==> web-instant-0.5.3.tgz: package/README.md <==
# Web Instant

> Create and Run React and Redux application instantly

[![Build Status][travis-badge]][travis]

## Why

- *Simple* - A single line of execution allows fast iteration for your MVP.
- *Instant* - Bootstrap your Web App instantly with configuration free.
- *Powerful* - Hot Reload, CSS Modules, PostCSS, and more for instant Mobile first and Offline first experience.

## Installation

`npm install -g web-instant`

## Usage

1. [Create](#create)
2. [Start](#start)
3. [Build](#build)

### <a name="create"></a>Create

Assuming the name of your Web App is `sample-app`.

```sh
web-instant create sample-app
```

or you can use `wi` instead.

```sh
wi create <any name your want>
```

![Alt text](docs/installation.png?raw=true "installation")

The creation time will take around 5 minutes long to complete since it will run async `npm install` for you.

![Alt text](docs/success.png?raw=true "success")

After creation, run `cd sample-app` to navigation to the newly created project.

### <a name="start"></a>Start

Once a project is successfully generated, you can just simply execute:

```sh
npm start
```

### <a name="build"></a>Build

`npm start` will also generate a build for you into `./public` folder.

However, you can also build it by your own by executing:

```sh
npm run build
```

Assets under `./public` will be production ready.

[travis]: https://travis-ci.org/yhjor1212/web-instant
[travis-badge]: https://img.shields.io/travis/yhjor1212/web-instant.svg

## Templates

You may also want to take a look for the template:

```
https://github.com/yhjor1212/web-instant-templates
```

==> web-instant-0.9.0.tgz: package/README.md <==
# Web Instant

> Create and Run React and Redux application instantly

[![Build Status][travis-badge]][travis]

## Why

- *Simple* - A single line of execution empowers the fast iteration for your MVP.
- *Instant* - Bootstrap your Web App instantly with configuration free.
- *Powerful* - Hot Reload, CSS Modules, PostCSS, and more are ready for instant Mobile first and Offline first experience.

## Installation

`npm install -g web-instant`

## Usage

1. [Create](#create)
2. [Generate](#generate)

### <a name="create"></a>Create

Assuming the name of your Web App is `sample-app`.

```sh
web-instant create sample-app
```

or you can use `wi` instead.

```sh
wi create <any name your want>
```

![Alt text](docs/installation.png?raw=true "installation")

The creation time will take around 5 minutes long to complete since it will run async `npm install` for you.

![Alt text](docs/success.png?raw=true "success")

After creation, run `cd sample-app` to navigation to the newly created project.

Once a project is successfully generated, you can just simply execute:

```sh
npm start
```

`npm start` will also generate a build for you into `./public` folder.

However, you can also build it by your own by executing:

```sh
npm run build
```

Assets under `./public` will be production ready.

[travis]: https://travis-ci.org/yhjor1212/web-instant
[travis-badge]: https://img.shields.io/travis/yhjor1212/web-instant.svg

### <a name="generate"></a>Generate

Generator command looks like this:
`wi generate <type> <feature> <name>`

Example:
```sh
wi generate component comment commentBox // ./src/comment/components/CommentBox.jsx
```

## Templates

You may also want to take a look for the template:

```
https://github.com/yhjor1212/web-instant-templates
```
